
/* Generated data (by glib-mkenums) */

#if !defined (__GCK_INSIDE_HEADER__) && !defined (GCK_COMPILATION)
#error "Only <gck/gck.h> can be included directly."
#endif

#ifndef __GCK_ENUM_TYPES_H__
#define __GCK_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "gck.h" */
GType gck_error_get_type (void) G_GNUC_CONST;
#define GCK_TYPE_ERROR (gck_error_get_type ())
GType gck_session_options_get_type (void) G_GNUC_CONST;
#define GCK_TYPE_SESSION_OPTIONS (gck_session_options_get_type ())
GType gck_uri_error_get_type (void) G_GNUC_CONST;
#define GCK_TYPE_URI_ERROR (gck_uri_error_get_type ())
GType gck_uri_flags_get_type (void) G_GNUC_CONST;
#define GCK_TYPE_URI_FLAGS (gck_uri_flags_get_type ())
G_END_DECLS

#endif /* __GCK_ENUM_TYPES_H__ */

/* Generated data ends here */

